from setuptools import setup, find_packages

setup(
    name='search-algos',
    version='0.1',
    description='A collection of searching algorithms for lists and dictionaries',
    author='Arpan Adhikari',
    author_email='codewitharpan@gmail.com',
    packages=find_packages()
)
